BaatoMultiPointGeoJson class

A GeoJSON MultiPoint feature.

Represents multiple point locations as a single feature.

Inheritance

Constructors

BaatoMultiPointGeoJson({required List<BaatoCoordinate> points, BaatoLayerProperties? properties})
Creates a new BaatoMultiPointGeoJson instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
points List<BaatoCoordinate>
The list of points in this MultiPoint feature.
final
properties BaatoLayerProperties?
The properties associated with this GeoJSON feature.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGeoJson({bool wrappedWithFeatureCollection = false}) Map<String, dynamic>
Converts this feature to a GeoJSON-compliant map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited