BaatoSymbolOption class

Configuration options for Baato map symbols.

This class provides a convenient way to configure symbols (markers) on a Baato map.

Constructors

BaatoSymbolOption({double? iconSize, String? iconImage = "baato_marker", double? iconRotate, Offset? iconOffset, String? iconAnchor, List<String>? fontNames = const ["OpenSans"], String? textField, double? textSize, double? textMaxWidth, double? textLetterSpacing, String? textJustify, String? textAnchor, double? textRotate, String? textTransform, Offset? textOffset, double? iconOpacity, String? iconColor, String? iconHaloColor, double? iconHaloWidth, double? iconHaloBlur, double? textOpacity, String? textColor, String? textHaloColor, double? textHaloWidth, double? textHaloBlur, BaatoCoordinate? geometry, int? zIndex, bool? draggable})
Creates a set of symbol configuration options.
const
BaatoSymbolOption.fromSymbolOptions(SymbolOptions symbolOptions)
Creates a BaatoSymbolOption from a MapLibre SymbolOptions object.
factory

Properties

draggable bool?
Whether the symbol is draggable.
final
fontNames List<String>?
Font names for the text. Not supported on web.
final
geometry BaatoCoordinate?
The geographical position of the symbol.
final
hashCode int
The hash code for this object.
no setterinherited
iconAnchor String?
The anchor position of the icon.
final
iconColor String?
The color of the icon.
final
iconHaloBlur double?
The blur radius of the icon's halo.
final
iconHaloColor String?
The color of the icon's halo.
final
iconHaloWidth double?
The width of the icon's halo.
final
iconImage String?
The name of the icon image to use.
final
iconOffset Offset?
The offset of the icon from its anchor position.
final
iconOpacity double?
The opacity of the icon.
final
iconRotate double?
The rotation angle of the icon in degrees clockwise.
final
iconSize double?
The size of the icon.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAnchor String?
The anchor position of the text.
final
textColor String?
The color of the text.
final
textField String?
The text to display with the symbol.
final
textHaloBlur double?
The blur radius of the text's halo.
final
textHaloColor String?
The color of the text's halo.
final
textHaloWidth double?
The width of the text's halo.
final
textJustify String?
The text justification.
final
textLetterSpacing double?
The letter spacing of the text.
final
textMaxWidth double?
The maximum width of the text.
final
textOffset Offset?
The offset of the text from its anchor position.
final
textOpacity double?
The opacity of the text.
final
textRotate double?
The rotation angle of the text in degrees clockwise.
final
textSize double?
The size of the text.
final
textTransform String?
The text transformation.
final
zIndex int?
The z-index of the symbol.
final

Methods

copyWith({double? iconSize, String? iconImage, double? iconRotate, Offset? iconOffset, String? iconAnchor, List<String>? fontNames, String? textField, double? textSize, double? textMaxWidth, double? textLetterSpacing, String? textJustify, String? textAnchor, double? textRotate, String? textTransform, Offset? textOffset, double? iconOpacity, String? iconColor, String? iconHaloColor, double? iconHaloWidth, double? iconHaloBlur, double? textOpacity, String? textColor, String? textHaloColor, double? textHaloWidth, double? textHaloBlur, BaatoCoordinate? geometry, int? zIndex, bool? draggable}) BaatoSymbolOption
Creates a copy of this BaatoSymbolOption with the given fields replaced with new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toSymbolOptions() SymbolOptions
Converts this BaatoSymbolOption to a MapLibre SymbolOptions object.

Operators

operator ==(Object other) bool
The equality operator.
inherited