InProgress class

Inheritance

Constructors

InProgress(double progress, {int completedResourceCount = 0, int requiredResourceCount = 0, int completedResourceSize = 0})

Properties

completedResourceCount int
final
completedResourceSize int
final
hashCode int
The hash code for this object.
no setterinherited
progress double
final
requiredResourceCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited