MapLibreMethodChannel class

Inheritance

Constructors

MapLibreMethodChannel()

Properties

hashCode int
The hash code for this object.
no setterinherited
onCameraIdlePlatform ArgumentCallbacks<CameraPosition?>
finalinherited
onCameraMovePlatform ArgumentCallbacks<CameraPosition>
finalinherited
onCameraMoveStartedPlatform ArgumentCallbacks<void>
finalinherited
onCameraTrackingChangedPlatform ArgumentCallbacks<MyLocationTrackingMode>
finalinherited
onCameraTrackingDismissedPlatform ArgumentCallbacks<void>
finalinherited
onFeatureDraggedPlatform ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onFeatureHoverPlatform ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onFeatureTappedPlatform ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onInfoWindowTappedPlatform ArgumentCallbacks<String>
finalinherited
onMapClickPlatform ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onMapIdlePlatform ArgumentCallbacks<void>
finalinherited
onMapLongClickPlatform ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onMapMouseMovePlatform ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onMapStyleLoadedPlatform ArgumentCallbacks<void>
finalinherited
onUserLocationUpdatedPlatform ArgumentCallbacks<UserLocation>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCircleLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) Future<void>
override
addFillExtrusionLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) Future<void>
override
addFillLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) Future<void>
override
addGeoJsonSource(String sourceId, Map<String, dynamic> geojson, {String? promoteId}) Future<void>
override
addHeatmapLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom}) Future<void>
override
addHillshadeLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom}) Future<void>
override
addImage(String name, Uint8List bytes, [bool sdf = false]) Future<void>
override
addImageSource(String imageSourceId, Uint8List bytes, LatLngQuad coordinates) Future<void>
override
addLayer(String imageLayerId, String imageSourceId, double? minzoom, double? maxzoom) Future<void>
override
addLayerBelow(String imageLayerId, String imageSourceId, String belowLayerId, double? minzoom, double? maxzoom) Future<void>
override
addLineLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) Future<void>
override
addRasterLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom}) Future<void>
override
addSource(String sourceId, SourceProperties properties) Future<void>
override
addSymbolLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) Future<void>
override
animateCamera(CameraUpdate cameraUpdate, {Duration? duration}) Future<bool?>
override
buildView(Map<String, dynamic> creationParams, OnPlatformViewCreatedCallback onPlatformViewCreated, Set<Factory<OneSequenceGestureRecognizer>>? gestureRecognizers) Widget
override
clearAmbientCache() Future
override
dispose() → void
override
easeCamera(CameraUpdate cameraUpdate, {Duration? duration, CameraAnimationInterpolation? interpolation}) Future<bool>
Animates the camera to a new position with a specified duration and interpolation.
override
editGeoJsonSource(String id, String data) Future<bool>
Edits a GeoJSON source with new data.
override
editGeoJsonUrl(String id, String url) Future<bool>
Edits a GeoJSON source with a new URL.
override
forceOnlineMode() Future<void>
Forces the map to use online mode (disables offline mode).
override
forceResizeWebMap() → void
override
getCustomHeaders() Future<Map<String, String>>
Returns the custom HTTP headers currently set on this map instance.
override
getFeatureState(String sourceId, String featureId, {String? sourceLayer}) Future<Map<String, dynamic>?>
override
getFilter(String layerId) Future
override
getLayerIds() Future<List>
override
getLayerVisibility(String layerId) Future<bool?>
Returns the visibility of a layer. Returns true if visible, false if hidden, null if layer not found.
override
getMetersPerPixelAtLatitude(double latitude) Future<double>
override
getSourceIds() Future<List>
override
getStyle() Future<String?>
Gets the current map style as JSON string.
override
getTelemetryEnabled() Future<bool>
override
getVisibleRegion() Future<LatLngBounds>
override
initPlatform(int id) Future<void>
override
invalidateAmbientCache() Future
override
matchMapLanguageWithDeviceDefault() Future<void>
override
moveCamera(CameraUpdate cameraUpdate) Future<bool?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryCameraPosition() Future<CameraPosition?>
Queries the current camera position.
override
queryRenderedFeatures(Point<double> point, List<String> layerIds, List<Object>? filter) Future<List>
override
queryRenderedFeaturesInRect(Rect rect, List<String> layerIds, String? filter) Future<List>
override
querySourceFeatures(String sourceId, String? sourceLayerId, List<Object>? filter) Future<List>
override
removeFeatureState(String sourceId, {String? featureId, String? stateKey, String? sourceLayer}) Future<void>
override
removeLayer(String imageLayerId) Future<void>
override
removeSource(String sourceId) Future<void>
override
requestMyLocationLatLng() Future<LatLng?>
override
resizeWebMap() → void
override
setCameraBounds({required double west, required double north, required double south, required double east, required int padding}) Future
override
setCustomHeaders(Map<String, String> headers, List<String> filter) Future<void>
Sets custom HTTP headers for requests made by this map instance.
override
setFeatureForGeoJsonSource(String sourceId, Map<String, dynamic> geojsonFeature) Future<void>
override
setFeatureState(String sourceId, String featureId, Map<String, dynamic> state, {String? sourceLayer}) Future<void>
override
setFilter(String layerId, dynamic filter) Future<void>
override
setGeoJsonSource(String sourceId, Map<String, dynamic> geojson) Future<void>
override
setLayerFilter(String layerId, String filter) Future<bool>
Sets a filter for a layer.
override
setLayerProperties(String layerId, Map<String, dynamic> properties) Future<void>
override
setLayerVisibility(String layerId, bool visible) Future<void>
override
setMapLanguage(String language) Future<void>
override
setMaximumFps(int fps) Future<void>
Performance Controls Sets the maximum frames per second for the map rendering.
override
setStyle(String styleString) Future<void>
Method to set style string
override
setTelemetryEnabled(bool enabled) Future<void>
override
setWebMapToCustomSize(Size size) Future<Size>
Sets the web map to a custom size for rendering. Returns the previous/initial size of the web map before this change.
override
takeSnapshot({int? width, int? height}) Future<Uint8List>
Takes a screenshot of the current map view as PNG bytes. Returns a Uint8List containing the PNG image data. Supported on all platforms (Android, iOS, Web).
override
toLatLng(Point<num> screenLocation) Future<LatLng>
override
toScreenLocation(LatLng latLng) Future<Point<num>>
override
toScreenLocationBatch(Iterable<LatLng> latLngs) Future<List<Point<num>>>
override
toString() String
A string representation of this object.
inherited
updateContentInsets(EdgeInsets insets, bool animated) Future<void>
override
updateImageSource(String imageSourceId, Uint8List? bytes, LatLngQuad? coordinates) Future<void>
override
updateMapOptions(Map<String, dynamic> optionsUpdate) Future<CameraPosition?>
override
updateMyLocationTrackingMode(MyLocationTrackingMode myLocationTrackingMode) Future<void>
override
waitUntilMapIsIdleAfterMovement() Future<void>
Waits until the map is idle after camera movement.
override
waitUntilMapTilesAreLoaded() Future<void>
Waits until all visible map tiles are loaded.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

useHybridComposition bool
getter/setter pair